@@ -98,6 +98,15 @@ class Project(AbstractProject, Configurable):
         # The fully qualified name of the sip module.
         Option('sip_module'),
 
+        # The list of files and directories, specified as glob patterns
+        # relative to the project directory, that should be included in a
+        # wheel.  If an element of list is a string then it is a pattern and
+        # files and directories are installed in the target directory.  If an
+        # element is a 2-tuple then the first part is the pattern and the
+        # second part is the name of a sub-directory relative to the target
+        # directory where the files and directories are installed.
+        Option('wheel_includes', option_type=list),
+
         # The user-configurable options.
         Option('quiet', option_type=bool,
                 help="disable all progress messages"),
@@ -108,6 +117,10 @@ class Project(AbstractProject, Configurable):
         Option('build_dir', help="the build directory", metavar="DIR"),
         Option('build_tag', help="the build tag to be used in the wheel name",
                 metavar="TAG", tools=['wheel']),
+        Option('manylinux', option_type=bool, inverted=True,
+                help="disable the use of manylinux in the platform tag used "
+                        "in the wheel name",
+                tools=['wheel']),
         Option('target_dir', default=get_python_lib(plat_specific=1),
                 help="the target installation directory", metavar="DIR",
                 tools=['build', 'install']),
@@ -234,10 +247,7 @@ class Project(AbstractProject, Configurable):
         eventual target directory.
         """
 
-        name_parts = self.sip_module.split('.')
-        name_parts[-1] = 'bindings'
-
-        return os.path.join(*name_parts)
+        return os.path.join(self.get_package_dir(), 'bindings')
 
     def get_distinfo_dir(self, target_dir):
         """ Return the name of the .dist-info directory for a target directory.
@@ -262,6 +272,21 @@ class Project(AbstractProject, Configurable):
 
         return options
 
+    def get_package_dir(self):
+        """ Return the name of the package directory relative to the eventual
+        target directory.  This is the directory containing the shared sip
+        module (if there is one) or the target directory (if not).  It will
+        normally be where the individual bindings are installed.
+        """
+
+        if self.sip_module:
+            name_parts = self.sip_module.split('.')
+            del name_parts[-1]
+
+            return os.path.join(*name_parts)
+
+        return ''
+
     def get_requires_dists(self):
         """ Return any 'Requires-Dist' to add to the project's meta-data. """
 
@@ -339,15 +364,14 @@ class Project(AbstractProject, Configurable):
 
         stderr = subprocess.STDOUT if and_stderr else subprocess.PIPE
 
-        pipe = subprocess.Popen(cmd, shell=True, stdin=subprocess.PIPE,
-                stdout=subprocess.PIPE, stderr=stderr)
+        with subprocess.Popen(cmd, shell=True, stdin=subprocess.PIPE,
+                stdout=subprocess.PIPE, stderr=stderr) as pipe:
+            for line in pipe.stdout:
+                yield str(line, encoding=sys.stdout.encoding)
 
-        for line in pipe.stdout:
-            yield str(line, encoding=sys.stdout.encoding)
-
-        rc = pipe.wait()
-        if rc != 0 and fatal:
-            raise UserException("'{0}' failed returning {1}".format(cmd, rc))
+        if pipe.returncode != 0 and fatal:
+            raise UserException(
+                    "'{0}' failed returning {1}".format(cmd, pipe.returncode))
 
     def run_command(self, args, *, fatal=True):
         """ Run a command and display the output if requested. """
@@ -377,11 +401,10 @@ class Project(AbstractProject, Configurable):
             # help we can.
             self.verbose = True
 
-        # Now that any help has been given we can report a missing
+        # Now that any help has been given we can report a problematic
         # pyproject.toml file.
-        if pyproject.pyproject_missing:
-            raise PyProjectException(
-                    "there is no such file in the current directory")
+        if pyproject.toml_error:
+            raise PyProjectException(pyproject.toml_error)
 
         # Make sure the configuration is complete.
         self.apply_user_defaults(tool)
@@ -492,6 +515,33 @@ class Project(AbstractProject, Configurable):
             # Make sure __init__.py is disabled.
             self.dunder_init = False
 
+        # Check any wheel includes are valid and make sure all elements are
+        # 2-tuples.
+        normalised = []
+
+        for wheel_include in self.wheel_includes:
+            if isinstance(wheel_include, str):
+                normalised.append((wheel_include, None))
+            else:
+                try:
+                    wheel_include, subdir = wheel_include
+                except TypeError:
+                    wheel_include = subdir = None
+
+                if isinstance(wheel_include, str) and isinstance(subdir, str):
+                    normalised.append((wheel_include, subdir))
+                else:
+                    raise PyProjectOptionException('wheel-includes',
+                            "elements must be strings or 2-tuples of strings")
+
+        self.wheel_includes = normalised
+
+        # Make sure that any .api directory is relative when building a wheel.
+        if tool == 'wheel' and self.api_dir:
+            if os.path.isabs(self.api_dir) or os.path.dirname(self.api_dir) == '..':
+                raise PyProjectOptionException('api-dir',
+                        "must be relative when building a wheel")
+
         # Verify the configuration of the builder and bindings.
         self.builder.verify_configuration(tool)
 
